@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 #
 # Electrum - lightweight Bitcoin client
 # Copyright (C) 2015 Thomas Voegtlin
@@ -23,13 +23,11 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-
 import webbrowser
 
-from util import *
+from .util import *
 from electrum.i18n import _
-from electrum.util import block_explorer_URL, format_satoshis, format_time
-from electrum.plugins import run_hook
+from electrum.util import block_explorer_URL
 from electrum.util import timestamp_to_datetime, profiler
 
 
@@ -72,7 +70,7 @@ class HistoryList(MyTreeWidget):
         self.wallet = self.parent.wallet
         h = self.wallet.get_history(self.get_domain())
         item = self.currentItem()
-        current_tx = item.data(0, Qt.UserRole).toString() if item else None
+        current_tx = item.data(0, Qt.UserRole) if item else None
         self.clear()
         fx = self.parent.fx
         if fx: fx.history_used_spot = False
@@ -100,8 +98,7 @@ class HistoryList(MyTreeWidget):
                     item.setTextAlignment(i, Qt.AlignRight)
                 if i!=2:
                     item.setFont(i, QFont(MONOSPACE_FONT))
-                    item.setTextAlignment(i, Qt.AlignVCenter)
-            if value < 0:
+            if value and value < 0:
                 item.setForeground(3, QBrush(QColor("#BC1E1E")))
                 item.setForeground(4, QBrush(QColor("#BC1E1E")))
             if tx_hash:
@@ -114,7 +111,7 @@ class HistoryList(MyTreeWidget):
         if self.permit_edit(item, column):
             super(HistoryList, self).on_doubleclick(item, column)
         else:
-            tx_hash = str(item.data(0, Qt.UserRole).toString())
+            tx_hash = item.data(0, Qt.UserRole)
             tx = self.wallet.transactions.get(tx_hash)
             self.parent.show_transaction(tx)
 
@@ -123,7 +120,7 @@ class HistoryList(MyTreeWidget):
         child_count = root.childCount()
         for i in range(child_count):
             item = root.child(i)
-            txid = str(item.data(0, Qt.UserRole).toString())
+            txid = item.data(0, Qt.UserRole)
             label = self.wallet.get_label(txid)
             item.setText(3, label)
 
@@ -142,7 +139,7 @@ class HistoryList(MyTreeWidget):
         if not item:
             return
         column = self.currentColumn()
-        tx_hash = str(item.data(0, Qt.UserRole).toString())
+        tx_hash = item.data(0, Qt.UserRole)
         if not tx_hash:
             return
         if column is 0:
